pub fn resolve_supported_model(model: &str) -> Result<&'static str, EmbedError>Expand description
Resolve a user-facing model name to the implemented Hugging Face id.
RAGFS currently implements only thenlper/gte-small (alias: gte-small).
pub fn resolve_supported_model(model: &str) -> Result<&'static str, EmbedError>Resolve a user-facing model name to the implemented Hugging Face id.
RAGFS currently implements only thenlper/gte-small (alias: gte-small).